FlutterCanary class

Constructors

FlutterCanary()
factory

Properties

appSecret ↔ String
getter/setter pair
debug ↔ bool
getter/setter pair
deviceid ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mockMap ↔ Map<String, MockItem>
getter/setter pair
mockOn ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String
getter/setter pair
user ↔ ValueNotifier<User?>
getter/setter pair

Methods

close(BuildContext context) → void
configure(String appSecret, {required String service, required String deviceid, bool debug = false}) → Future<void>
configValue(String key, {String? def}) → String?
获取配置的参数值
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
options() → Widget
showOptions(BuildContext context) → void
start({NetLogMode mode = NetLogMode.afNetworking}) → void
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

channel ↔ MethodChannel
getter/setter pair
instance → FlutterCanary
no setter
platformVersion → Future<String?>
no setter

Static Methods

pop<T>({bool animated = true}) → Future<T?>