MockItem class

Annotations
  • @JsonSerializable.new()

Constructors

MockItem(int id, String name, String path, bool enabled, {int? sceneid, List<MockScene>? scenes})
MockItem.fromJson(Map<String, dynamic> json)
factory

Properties

enabled ↔ bool
激活状态
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
name ↔ String
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sceneid ↔ int?
getter/setter pair
sceneMode → String
no setter
scenes ↔ List<MockScene>?
getter/setter pair

Methods

match(int? sceneid, Map<String, dynamic> queryParameters) → int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited